@@ -213,15 +213,19 @@ def _terminate():
 def _api2dict(api, index):
     return { 'struct_version': api.structVersion,
              'type': api.type,
-             'name': ffi.string(api.name).decode(),
+             'name': ffi.string(api.name).decode(errors='ignore'),
              'api_idx': index,
              'device_count': api.deviceCount,
              'default_input_device_index': api.defaultInputDevice,
              'default_output_device_index': api.defaultOutputDevice }
 
 def _dev2dict(dev, index):
+    if 'DirectSound' in list(apis())[dev.hostApi]['name']:
+        enc = 'mbcs'
+    else:
+        enc = 'utf-8'
     return { 'struct_version': dev.structVersion,
-             'name': ffi.string(dev.name).decode(),
+             'name': ffi.string(dev.name).decode(encoding=enc, errors='ignore'),
              'device_index': index,
              'host_api_index': dev.hostApi,
              'input_channels': dev.maxInputChannels,
@@ -608,15 +612,14 @@ class Stream(object):
         if isinstance(data, np.ndarray):
             if data.dtype != self.output_format:
                 data = np.array(data, dtype=self.output_format)
-            data = data
         elif isinstance(data, list):
             data = np.array(data, dtype=self.output_format)
         if len(data.shape) == 1 and self.output_channels != 1:
             # replicate first channel and broadcast to (chan, 1)
             data = np.tile(data, (self.output_channels, 1)).T
-        if data.shape[1] != self.output_channels:
+        if data.shape != (num_frames, self.output_channels):
             error = 'Can not broadcast array of shape {} to {}'.format(
-                data.shape, (len(data), self.output_channels))
+                data.shape, (num_frames, self.output_channels))
             raise ValueError(error)
         data = data.flatten().tostring()
         err = _pa.Pa_WriteStream(self._stream[0], data, num_frames)
